![Discord](https://img.shields.io/discord/1213589765484576818)
![Python Version](https://img.shields.io/pypi/pyversions/rio-ui)
![Version](https://img.shields.io/pypi/v/rio-ui)
![License](https://img.shields.io/pypi/l/rio-ui)

<!-- TODO: Stars -->

<!-- https://shields.io/badges -->

<img src="https://gitlab.com/team-rio/rio/-/raw/dev/rio/assets/hosted/rio-logos/logo-and-text-horizontal.png" alt="Rio Logo" style="width: 30rem" />

🌊 You've arrived at **Rio**, an easy to use framework for creating websites and
apps.

🐍 Rio is based **entirely on Python**. You **won't need a single line of HTML, CSS, or
JavaScript** to create beautiful, modern apps.

[Tutorial](https://rio.dev/docs/tutorial-simple-dashboard/1-rio-setup) - [Examples](https://rio.dev/examples) - [Discord](https://discord.gg/7ejXaPwhyH) -  [docs](https://rio.dev/docs) - [Source Code](https://gitlab.com/team-rio/rio)

Rio brings React-style components to Python. Pull from a wealth of built-in
components and combine them to create your own custom components. Then combine
those into entire apps. Best of all, Rio apps can run both locally on your
machine and on the web.

## Features 🧩

- Modern, **declarative UI** framework
- **100% Python** - Zero HTML, CSS, or JavaScript required
- Over **50 Built-in components** for common UI elements, such as `rio.Switch`, `rio.Button`, and `rio.Text`, and many more
- Integrates with **modern Python tooling**: Thanks to being **entirely Type Safe** editors can give you instant suggestions and highlight problems right away
- Apps can run **both locally and on the web**
- **Open Source & Free forever**

## Installation 🛠️

Rio is available on PyPI, so you can install it using pip:

```bash
pip install rio-ui
```

## Getting Started 🎓

Rio comes with a very helpful command line utility to help you out. Create a new project in one short command:

```bash
rio new
```

You can choose from a variety of built-in templates to get you started. Here's a complete example to create a project based on the tic-tac-toe template:

```bash
rio new my-app --type website --template 'Tic-Tac-Toe'
cd my-project
rio run
```

You'll have your first app up and running in seconds!

## How it works 🧠

TODO: Minimal example
